summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/ksnewstuff.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/ksnewstuff.h')
-rw-r--r--kstars/kstars/ksnewstuff.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kstars/kstars/ksnewstuff.h b/kstars/kstars/ksnewstuff.h
index c94bb18a..69e8fbc4 100644
--- a/kstars/kstars/ksnewstuff.h
+++ b/kstars/kstars/ksnewstuff.h
@@ -17,12 +17,12 @@
/**
*@class KSNewStuff
*Subclass of KNewStuff, which provides a GUI for downloading extra
*application data from the internet. The KStars version is cutomized to
*parse the newly downloaded data and incorporate it immediately into
*the program.
*@note This class is only compiled if the user has KDE >= 3.2.90, because
*earlier versions of KDE did not have KNewStuff.
*@author Jason Harris
*@version 1.0
*/
@@ -36,12 +36,12 @@
#include <kdebug.h>
#include <tqobject.h>
-#include <knewstuff/knewstuff.h>
+#include <tdenewstuff/knewstuff.h>
class KDirWatch;
class KStars;
-class KSNewStuff : public TQObject, public KNewStuff
+class KSNewStuff : public TQObject, public TDENewStuff
{
Q_OBJECT
@@ -55,7 +55,7 @@ class KSNewStuff : public TQObject, public KNewStuff
/**
*Install new application data
*@p fileName the name of the file to be installed
*@note overloaded from KNewStuff
*/
bool install( const TQString &fileName );
@@ -17,12 +17,12 @@
/**
*@class KSNewStuff
- *Subclass of KNewStuff, which provides a GUI for downloading extra
+ *Subclass of TDENewStuff, which provides a GUI for downloading extra
*application data from the internet. The KStars version is cutomized to
*parse the newly downloaded data and incorporate it immediately into
@@ -17,12 +17,12 @@
*the program.
*@note This class is only compiled if the user has KDE >= 3.2.90, because
- *earlier versions of KDE did not have KNewStuff.
+ *earlier versions of KDE did not have TDENewStuff.
*@author Jason Harris
*@version 1.0
@@ -55,7 +55,7 @@ class KSNewStuff : public TQObject, public KNewStuff
*Install new application data
*@p fileName the name of the file to be installed
- *@note overloaded from KNewStuff
+ *@note overloaded from TDENewStuff
*/
bool install( const TQString &fileName );